
SQL Table
=========

.. figure:: icons/file.png

Reads data from a SQL database.

Signals
-------

**Inputs**:

    -  (None)

**Outputs**:

    -  **Data**

        Attribute-valued data from the database

Description
-----------

The **SQL** widget accesses data stored in a sql database. It can
connect to PostgreSQL (requires psycopg2 module) or SQL Server
(requires pymssql module).
